
# cherry.models

::: cherry.models.polyak_average

::: cherry.models.RandomPolicy
    selection:
      members:
        - __init__

## cherry.models.atari

::: cherry.models.atari.NatureFeatures
    selection:
      members:
        - __init__
        - forward

::: cherry.models.atari.NatureActor
    selection:
      members:
        - __init__
        - forward

::: cherry.models.atari.NatureCritic
    selection:
      members:
        - __init__
        - forward

## cherry.models.robotics

::: cherry.models.robotics.RoboticsMLP
    selection:
      members:
        - __init__
        - forward

::: cherry.models.robotics.RoboticsActor
    selection:
      members:
        - __init__
        - forward

::: cherry.models.robotics.LinearValue
    selection:
      members:
        - __init__
        - fit
        - forward

## cherry.models.tabular

::: cherry.models.tabular.StateValueFunction
    selection:
      members:
        - __init__
        - forward

::: cherry.models.tabular.ActionValueFunction
    selection:
      members:
        - __init__
        - forward

